@@ -10,7 +10,7 @@ use crate::{
       get as get_config, reload as reload_config, BeforeDevCommand, ConfigHandle, FrontendDist,
     },
   },
-  interface::{AppInterface, DevProcess, ExitReason, Interface},
+  interface::{AppInterface, ExitReason, Interface},
   CommandExt, ConfigValue, Result,
 };
 
@@ -338,30 +338,6 @@ pub fn setup(interface: &AppInterface, options: &mut Options, config: ConfigHand
   Ok(())
 }
 
-pub fn wait_dev_process<
-  C: DevProcess + Send + 'static,
-  F: Fn(Option<i32>, ExitReason) + Send + Sync + 'static,
->(
-  child: C,
-  on_exit: F,
-) {
-  std::thread::spawn(move || {
-    let code = child
-      .wait()
-      .ok()
-      .and_then(|status| status.code())
-      .or(Some(1));
-    on_exit(
-      code,
-      if child.manually_killed_process() {
-        ExitReason::TriggeredKill
-      } else {
-        ExitReason::NormalExit
-      },
-    );
-  });
-}
-
 pub fn on_app_exit(code: Option<i32>, reason: ExitReason, exit_on_panic: bool, no_watch: bool) {
   if no_watch
     || (!matches!(reason, ExitReason::TriggeredKill)
