@@ -7,6 +7,22 @@ use anyhow::Context;
 use crate::helpers::cross_command;
 use std::{fmt::Display, path::Path, process::Command};
 
+pub fn manager_version(package_manager: &str) -> Option<String> {
+  cross_command(package_manager)
+    .arg("-v")
+    .output()
+    .map(|o| {
+      if o.status.success() {
+        let v = String::from_utf8_lossy(o.stdout.as_slice()).to_string();
+        Some(v.split('\n').next().unwrap().to_string())
+      } else {
+        None
+      }
+    })
+    .ok()
+    .unwrap_or_default()
+}
+
 #[derive(Debug, PartialEq, Eq, Clone, Copy)]
 pub enum PackageManager {
   Npm,
@@ -35,7 +51,16 @@ impl Display for PackageManager {
 }
 
 impl PackageManager {
-  pub fn from_project<P: AsRef<Path>>(path: P) -> Vec<Self> {
+  /// Detects package manager from the given directory, falls back to [`PackageManager::Npm`].
+  pub fn from_project<P: AsRef<Path>>(path: P) -> Self {
+    Self::all_from_project(path)
+      .first()
+      .copied()
+      .unwrap_or(Self::Npm)
+  }
+
+  /// Detects all possible package managers from the given directory.
+  pub fn all_from_project<P: AsRef<Path>>(path: P) -> Vec<Self> {
     let mut found = Vec::new();
 
     if let Ok(entries) = std::fs::read_dir(path) {
@@ -47,7 +72,15 @@ impl PackageManager {
         } else if name.as_ref() == "pnpm-lock.yaml" {
           found.push(PackageManager::Pnpm);
         } else if name.as_ref() == "yarn.lock" {
-          found.push(PackageManager::Yarn);
+          let yarn = if manager_version("yarn")
+            .map(|v| v.chars().next().map(|c| c > '1').unwrap_or_default())
+            .unwrap_or(false)
+          {
+            PackageManager::YarnBerry
+          } else {
+            PackageManager::Yarn
+          };
+          found.push(yarn);
         } else if name.as_ref() == "bun.lockb" {
           found.push(PackageManager::Bun);
         } else if name.as_ref() == "deno.lock" {
@@ -70,7 +103,11 @@ impl PackageManager {
     }
   }
 
-  pub fn install<P: AsRef<Path>>(&self, dependencies: &[String], app_dir: P) -> crate::Result<()> {
+  pub fn install<P: AsRef<Path>>(
+    &self,
+    dependencies: &[String],
+    frontend_dir: P,
+  ) -> crate::Result<()> {
     let dependencies_str = if dependencies.len() > 1 {
       "dependencies"
     } else {
@@ -85,11 +122,16 @@ impl PackageManager {
         .join(", ")
     );
 
-    let status = self
-      .cross_command()
-      .arg("add")
-      .args(dependencies)
-      .current_dir(app_dir)
+    let mut command = self.cross_command();
+    command.arg("add");
+
+    match self {
+      PackageManager::Deno => command.args(dependencies.iter().map(|d| format!("npm:{d}"))),
+      _ => command.args(dependencies),
+    };
+
+    let status = command
+      .current_dir(frontend_dir)
       .status()
       .with_context(|| format!("failed to run {self}"))?;
 
@@ -100,7 +142,11 @@ impl PackageManager {
     Ok(())
   }
 
-  pub fn remove<P: AsRef<Path>>(&self, dependencies: &[String], app_dir: P) -> crate::Result<()> {
+  pub fn remove<P: AsRef<Path>>(
+    &self,
+    dependencies: &[String],
+    frontend_dir: P,
+  ) -> crate::Result<()> {
     let dependencies_str = if dependencies.len() > 1 {
       "dependencies"
     } else {
@@ -123,7 +169,7 @@ impl PackageManager {
         "remove"
       })
       .args(dependencies)
-      .current_dir(app_dir)
+      .current_dir(frontend_dir)
       .status()
       .with_context(|| format!("failed to run {self}"))?;
 
@@ -137,7 +183,7 @@ impl PackageManager {
   pub fn current_package_version<P: AsRef<Path>>(
     &self,
     name: &str,
-    app_dir: P,
+    frontend_dir: P,
   ) -> crate::Result<Option<String>> {
     let (output, regex) = match self {
       PackageManager::Yarn => (
@@ -145,7 +191,7 @@ impl PackageManager {
           .args(["list", "--pattern"])
           .arg(name)
           .args(["--depth", "0"])
-          .current_dir(app_dir)
+          .current_dir(frontend_dir)
           .output()?,
         None,
       ),
@@ -154,7 +200,7 @@ impl PackageManager {
           .arg("info")
           .arg(name)
           .arg("--json")
-          .current_dir(app_dir)
+          .current_dir(frontend_dir)
           .output()?,
         Some(regex::Regex::new("\"Version\":\"([\\da-zA-Z\\-\\.]+)\"").unwrap()),
       ),
@@ -163,7 +209,7 @@ impl PackageManager {
           .arg("list")
           .arg(name)
           .args(["--parseable", "--depth", "0"])
-          .current_dir(app_dir)
+          .current_dir(frontend_dir)
           .output()?,
         None,
       ),
@@ -173,7 +219,7 @@ impl PackageManager {
           .arg("list")
           .arg(name)
           .args(["version", "--depth", "0"])
-          .current_dir(app_dir)
+          .current_dir(frontend_dir)
           .output()?,
         None,
       ),
